Nmap Development mailing list archives

[PATCH] Slightly update ip_is_reserved()


From: Kris Katterjohn <katterjohn () gmail com>
Date: Mon, 11 Dec 2006 18:50:59 -0600

This updates ip_is_reserved() in nmap.cc a tad. Or is it not that
important to have this function updated?

It's a diff against 4.21ALPHA1

Thanks,
Kris Katterjohn
--- x/nmap.cc   2006-12-10 18:34:36.000000000 -0600
+++ y/nmap.cc   2006-12-11 18:44:53.000000000 -0600
@@ -347,13 +347,12 @@ static int ip_is_reserved(struct in_addr
       break;
     }
 
-
-  /* 077-079/8 is IANA reserved */
-  if (i1 >= 77 && i1 <= 79)
+  /* 092-95/8 is IANA reserved */
+  if (i1 >= 92 && i1 <= 95)
     return 1;
 
-  /* 092-123/8 is IANA reserved */
-  if (i1 >= 92 && i1 <= 123)
+  /* 100-120/8 is IANA reserved */
+  if (i1 >= 100 && i1 <= 120)
     return 1;
 
   /* 172.16.0.0/12 is reserved for private nets by RFC1819 */

_______________________________________________
Sent through the nmap-dev mailing list
http://cgi.insecure.org/mailman/listinfo/nmap-dev
Archived at http://SecLists.Org

Current thread: